@@ -12,7 +12,7 @@ from django.views.generic import View
 
 from .utils import status
 from .utils.auth import AnonimousAuthenticator
-from .utils.emmiter import JSONEmitter
+from .utils.emmiter import HTMLTemplateEmmiter, JSONEmitter
 from .utils.exceptions import HttpError
 from .utils.tools import as_tuple
 from .utils.response import Response
@@ -271,31 +271,42 @@ class ApiMapResource(ResourceView):
     """ Simple JSON Api Map.
     """
     log = False
-    emitters = JSONEmitter
+    emitters = HTMLTemplateEmmiter, JSONEmitter
     authenticators = AnonimousAuthenticator
+    template = 'api/apimap.html'
 
     def get(self, *args, **Kwargs):
-        resources = set()
-        api_map = dict()
+        api_map = []
         for key, rinfo in sorted(self.api._map.iteritems(), key=lambda x: x[1].get('urlregex')):
             rinfo = self.api._map[key]
             r = rinfo['resource']
-            if r.meta.urlname in resources:
-                continue
-            resources.add(rinfo['urlname'])
 
             result = dict(
                 name = rinfo['urlname'],
                 methods = r.allowed_methods,
-                model = r.model.__name__ if r.model else r.model,
             )
+
+            if r.model:
+                result['resource'] = r.model.__name__
+
             form = r.get_form()
-            if form:
-                result['fields'] = dict(
+            if form and ('POST' in r.allowed_methods or 'PUT' in r.allowed_methods):
+                result['fields'] = [
                     (name, dict(required = f.required, help = smart_unicode(f.help_text + '')))
                         for name, f in form.base_fields.iteritems()
                         if not (isinstance(f, ModelChoiceField) and f.choices.queryset.model in r.meta.models)
-                )
+                ]
             key = rinfo['urlregex'].replace("(?P", "").replace("[^/]+)", "").replace("?:", "").replace("$", "")
-            api_map[key] = result
-        return api_map
+
+            if rinfo['kwargs'].get('authenticators'):
+                result['auth'] = [str(a) for a in as_tuple(rinfo['kwargs'].get('authenticators'))]
+
+            elif self.api.kwargs.get('authenticators'):
+                result['auth'] = [str(a) for a in as_tuple(self.api.kwargs.get('authenticators'))]
+
+            elif r.authenticators:
+                result['auth'] = [str(a) for a in as_tuple(r.authenticators)]
+
+            api_map.append((key, result))
+
+        return (self.api.str_version, api_map)
